@@ -43,7 +43,6 @@
 #'
 #' @examples
 #' library(dplyr)
-#' library(timetk)
 #'
 #' m4_monthly %>%
 #'     group_by(id) %>%
@@ -145,7 +144,7 @@ tk_augment_differences.grouped_df <- function(.data,
                 .names      = .names
             )
         )) %>%
-        dplyr::select(-data) %>%
+        dplyr::select(-"data") %>%
         tidyr::unnest(cols = nested.col) %>%
         dplyr::group_by_at(.vars = group_names)
 }
