@@ -42,8 +42,6 @@
 #'
 #' @examples
 #' library(dplyr)
-#' library(stringr)
-#' library(timetk)
 #'
 #' # Single Column | Multiple Rolling Windows
 #' FANG %>%
@@ -55,7 +53,7 @@
 #'         .period  = c(10, 30, 60, 90),
 #'         .f       = mean,
 #'         .partial = TRUE,
-#'         .names   = str_c("MA_", c(10, 30, 60, 90))
+#'         .names   = stringr::str_c("MA_", c(10, 30, 60, 90))
 #'     ) %>%
 #'     ungroup()
 #'
@@ -184,7 +182,7 @@ tk_augment_slidify.grouped_df <- function(.data,
                 .names     = .names
             )
         )) %>%
-        dplyr::select(-data) %>%
+        dplyr::select(-"data") %>%
         tidyr::unnest(cols = nested.col) %>%
         dplyr::group_by_at(.vars = group_names)
 }
