@@ -104,7 +104,6 @@
 #'
 #' @examples
 #' library(dplyr)
-#' library(timetk)
 #'
 #' walmart_sales_weekly %>%
 #'     group_by(id) %>%
@@ -166,7 +165,7 @@ plot_anomaly_diagnostics <- function(
     date_var_expr <- rlang::enquo(.date_var)
 
     if (!is.data.frame(.data)) {
-        rlang::abort(".data is not a data-frame or tibble. Please supply a data.frame or tibble.")
+        rlang::abort("`.data` must be a a data-frame or tibble. Please supply a data.frame or tibble.")
     }
     if (rlang::quo_is_missing(date_var_expr)) {
         rlang::abort(".date_var is missing. Please supply a date or date-time column.")
@@ -301,10 +300,10 @@ plot_anomaly_diagnostics.data.frame <- function(
     # Add line
     g <- g +
         ggplot2::geom_line(
-            color    = .line_color,
-            size     = .line_size,
-            linetype = .line_type,
-            alpha    = .line_alpha
+            color     = .line_color,
+            linewidth = .line_size,
+            linetype  = .line_type,
+            alpha     = .line_alpha
         )
 
     # Add Outliers
