@@ -37,7 +37,7 @@ maybe_register_s3_methods <- function() {
 
     # ----------------------------------------------------------------------------
 
-    if (rlang::is_installed("tune") && utils::packageVersion("tune") >= "0.1.1.9000") {
+    if (rlang::is_installed("tune (>= 0.1.2)")) {
 
         req_pkgs_names <- grep("^required_pkgs\\.", names, value = TRUE)
         req_pkgs_classes <- gsub("required_pkgs.", "", req_pkgs_names)
