@@ -1,5 +1,5 @@
 context("Testing tk_index")
-
+library(dplyr)
 FB_tbl    <- FANG %>% dplyr::filter(symbol == "FB")
 FB_xts    <- FB_tbl %>% tk_xts(silent = TRUE)
 FB_zoo    <- FB_tbl %>% tk_zoo(silent = TRUE)
@@ -13,30 +13,27 @@ FB_ts     <- FB_tbl %>% tk_ts(start = 2015, freq = 252, silent = TRUE)
 test_that("tk_index(default) test returns correct format.", {
     # Not designed to work with objects of class numeric
     expect_warning(tk_index(4))
-    expect_warning(
-        expect_false(
-            has_timetk_idx(4)
-            )
-        )
+    expect_warning(res <- has_timetk_idx(4))
+    expect_false(res)
 })
 
 test_that("tk_index(ts) test returns correct format.", {
 
     # Test if object has timetk index
-    expect_true(tk_ts(FB_tbl, freq = 252, start = 2015, silent = TRUE) %>%
+    expect_true(tk_ts(FB_tbl, frequency = 252, start = 2015, silent = TRUE) %>%
                     has_timetk_idx())
 
     # Return regularized dates
-    test_index_1 <- tk_ts(FB_tbl, freq = 252, start = 2015, silent = TRUE) %>%
+    test_index_1 <- tk_ts(FB_tbl, frequency = 252, start = 2015, silent = TRUE) %>%
         tk_index(timetk_idx = FALSE)
     expect_equal(class(test_index_1), "numeric")
-    expect_equal(length(test_index_1), 1008)
+    expect_length(test_index_1, 1008)
 
     # Return non-regularized dates (aka timetk index)
-    test_index_2 <- tk_ts(FB_tbl, freq = 252, start = 2015, silent = TRUE) %>%
-        tk_index(timetk_idx = TRUE)
-    expect_equal(class(test_index_2), "Date")
-    expect_equal(length(test_index_2), 1008)
+    expect_tz_warning(test_index_2 <- tk_ts(FB_tbl, frequency = 252, start = 2015, silent = TRUE) %>%
+        tk_index(timetk_idx = TRUE))
+    expect_s3_class(test_index_2, "Date")
+    expect_length(test_index_2, 1008)
 
     # No timetk index
     expect_warning(
@@ -51,20 +48,20 @@ test_that("tk_index(ts) test returns correct format.", {
 test_that("tk_index(zooreg) test returns correct format.", {
 
     # Test if object has timetk index
-    expect_true(tk_zooreg(FB_tbl, freq = 252, start = 2015, silent = TRUE) %>%
+    expect_true(tk_zooreg(FB_tbl, frequency = 252, start = 2015, silent = TRUE) %>%
                           has_timetk_idx())
 
     # Return regularized dates
-    test_index_3 <- tk_zooreg(FB_tbl, freq = 252, start = 2015, silent = TRUE) %>%
+    test_index_3 <- tk_zooreg(FB_tbl, frequency = 252, start = 2015, silent = TRUE) %>%
         tk_index(timetk_idx = FALSE)
-    expect_equal(class(test_index_3), "numeric")
-    expect_equal(length(test_index_3), 1008)
+    expect_type(test_index_3, "double")
+    expect_length(test_index_3, 1008)
 
     # Return non-regularized dates (aka timetk index)
-    test_index_4 <- tk_zooreg(FB_tbl, freq = 252, start = 2015, silent = TRUE) %>%
+    test_index_4 <- tk_zooreg(FB_tbl, frequency = 252, start = 2015, silent = TRUE) %>%
         tk_index(timetk_idx = TRUE)
-    expect_equal(class(test_index_4), "Date")
-    expect_equal(length(test_index_4), 1008)
+    expect_s3_class(test_index_4, "Date")
+    expect_length(test_index_4, 1008)
 
 })
 
@@ -75,8 +72,8 @@ test_that("tk_index(tbl) test returns correct format.", {
 
     # Return vector of dates
     test_index_3 <- FB_tbl %>% tk_index(timetk_idx = FALSE)
-    expect_equal(class(test_index_3), "Date")
-    expect_equal(length(test_index_3), 1008)
+    expect_s3_class(test_index_3, "Date")
+    expect_length(test_index_3, 1008)
 
     # No date or date time
     expect_error(tk_index(mtcars))
@@ -84,14 +81,13 @@ test_that("tk_index(tbl) test returns correct format.", {
 })
 
 test_that("tk_index(xts) test returns correct format.", {
-
     # Test if object has timetk index
     expect_false(FB_xts %>% has_timetk_idx())
 
     # Return vector of dates
-    test_index_5 <- FB_xts %>% tk_index(timetk_idx = FALSE)
-    expect_equal(class(test_index_5), "Date")
-    expect_equal(length(test_index_5), 1008)
+    expect_tz_warning(test_index_5 <- FB_xts %>% tk_index(timetk_idx = FALSE))
+    expect_s3_class(test_index_5, "Date")
+    expect_length(test_index_5, 1008)
 
 })
 
@@ -101,10 +97,9 @@ test_that("tk_index(zoo) test returns correct format.", {
     expect_false(FB_zoo %>% has_timetk_idx())
 
     # Return vector of dates
-    test_index_6 <- FB_zoo %>%
-        tk_index(timetk_idx = FALSE)
-    expect_equal(class(test_index_6), "Date")
-    expect_equal(length(test_index_6), 1008)
+    expect_tz_warning(test_index_6 <- tk_index(FB_zoo, timetk_idx = FALSE))
+    expect_s3_class(test_index_6, "Date")
+    expect_length(test_index_6, 1008)
 
 })
 
@@ -121,8 +116,7 @@ test_that("tk_index(ets) test returns correct format.", {
     # Return vector of numeric regularized dates
     test_index_7 <- fit_ets %>%
         tk_index(timetk_idx = FALSE)
-    expect_equal(class(test_index_7), "numeric")
-    expect_equal(length(test_index_7), 72)
+    expect_type(test_index_7, "double")
 
 })
 
@@ -139,7 +133,7 @@ test_that("tk_index(forecast) test returns correct format.", {
     test_index_8 <- fcast_ets %>%
         tk_index(timetk_idx = FALSE)
     expect_equal(class(test_index_8), "numeric")
-    expect_equal(length(test_index_8), 72)
+    expect_length(test_index_8, 72)
 
 })
 
@@ -274,7 +268,7 @@ test_that("tk_index(nnetar) test returns correct format.", {
 })
 
 test_that("tk_index(fracdiff) test returns correct format.", {
-
+    skip_if_not_installed("fracdiff")
     # ARFIMA model (class = "fracdiff")
     x <- fracdiff::fracdiff.sim( 100, ma=-.4, d=.3)$series
     fit_arfima <- forecast::arfima(x)
@@ -298,17 +292,16 @@ test_that("tk_index(decomposed.ts) test returns correct format.", {
 
     data_ts <- USAccDeaths %>%
         tk_tbl() %>%
-        mutate(index = as_date(index)) %>%
-        tk_ts(start = 1973, freq = 12, silent = T)
+        dplyr::mutate(index = lubridate::as_date(index)) %>%
+        tk_ts(start = 1973, frequency = 12, silent = TRUE)
 
-    fit <- decompose(data_ts)
+    fit <- stats::decompose(data_ts)
 
-    test <- has_timetk_idx(fit)
-    expect_true(test)
+    expect_true(has_timetk_idx(fit))
 
-    expect_equal(tk_index(fit) %>% class(), "numeric")
-
-    expect_equal(tk_index(fit, timetk_idx = T) %>% class(), "Date")
+    expect_type(tk_index(fit), "double")
+    expect_tz_warning(res <- tk_index(fit, timetk_idx = TRUE))
+    expect_s3_class(res, "Date")
 
 
 })
