@@ -35,11 +35,11 @@ test_that("tbl to xts test returns xts with correct rows and columns.", {
     expect_equal(colnames(test_xts_3), select)
 
     # Test back-ticked columns
-    tib <- tibble(
+    tib <- dplyr::tibble(
         `date column` = seq.Date(from = as.Date("2017-01-01"), by = "day", length.out = 10),
         `my value` = 1:10
     )
-    test <- tk_xts(tib, silent = T)
+    test <- tk_xts(tib, silent = TRUE)
     expect_equal(nrow(test), 10)
     expect_equal(ncol(test), 1)
     expect_is(test, "xts")
@@ -75,7 +75,7 @@ test_that("zoo to xts test returns xts with correct rows and columns.", {
 # Default is xts::xts() for other objects; only test zoo
 test_that("ts to xts test returns xts with correct rows and columns.", {
     # Use date column to specify order
-    test_xts_6 <- tk_ts(FB_tbl, silent = TRUE) %>% tk_xts()
+    expect_tz_warning(test_xts_6 <- tk_ts(FB_tbl, silent = TRUE) %>% tk_xts())
     expect_equal(nrow(test_xts_6), 1008)
     expect_equal(ncol(test_xts_6), 6)
 
